@@ -1,11 +1,9 @@
 package Net::Riak::Role::PBC::Object;
 {
-  $Net::Riak::Role::PBC::Object::VERSION = '0.1701';
+  $Net::Riak::Role::PBC::Object::VERSION = '0.1702';
 }
-
 use JSON;
 use Moose::Role;
-use Data::Dumper;
 use List::Util 'first';
 
 sub store_object {
@@ -13,19 +11,22 @@ sub store_object {
 
     die "Storing object without a key is not supported in the PBC interface" unless $object->key;
 
-    my $value = (ref $object->data && $object->content_type eq 'application/json') 
+    my $value = (ref $object->data && $object->content_type eq 'application/json')
             ? JSON::encode_json($object->data) : $object->data;
 
     my $content = {
         content_type => $object->content_type,
         value => $value,
-        usermeta => undef
     };
 
     if ($object->has_links) {
         $content->{links} = $self->_links_for_message($object);
     }
 
+    if ($object->has_meta) {
+        $content->{usermeta} = $self->_metas_for_message($object);
+    }
+
     $self->send_message(
         PutReq => {
             bucket  => $object->bucket->name,
@@ -90,7 +91,11 @@ sub populate_object {
         $self->_populate_links($object, $content->links);
     }
 
-    my $data = ($object->content_type eq 'application/json') 
+    if($content->usermeta) {
+        $self->_populate_metas($object, $content->usermeta);
+    }
+
+    my $data = ($object->content_type eq 'application/json')
         ? JSON::decode_json($content->value) : $content->value;
 
     $object->exists(1);
@@ -113,7 +118,7 @@ sub retrieve_sibling {
 
     # hack for loading 1 sibling
     if ($params->{vtag}) {
-        $resp->{content} = [ 
+        $resp->{content} = [
             first {
                 $_->vtag eq $params->{vtag}
             } @{$resp->content}
@@ -129,7 +134,7 @@ sub retrieve_sibling {
     $sibling->_jsonize($object->_jsonize);
 
     $self->populate_object($sibling, $resp);
-    
+
     $sibling;
 }
 
@@ -145,7 +150,7 @@ Net::Riak::Role::PBC::Object
 
 =head1 VERSION
 
-version 0.1701
+version 0.1702
 
 =head1 AUTHOR
 
